Changelog
---------

<!-- Do not edit. This file is automatically generated from changelog.yaml.-->

**0.25.0 (2020-01-21)**

* Show character count when composing (#121)
* Include changelog and license in sourceballs (#133)
* Fix searching by hashtag which include the '#' (#134)
* Upgrade search to v2 (#135)
* Fix compatibility with Python < 3.6 (don't use fstrings)

**0.24.0 (2019-09-18)**

* On Windows store config files under %APPDATA%
* CLI: Don't use ANSI colors if not supported by terminal or when not in a tty
* TUI: Implement deleting own status messages
* TUI: Improve rendering of reblogged statuses (thanks @dlax)
* TUI: Set urwid encoding to UTF-8 (thanks @bearzk)

**0.23.1 (2019-09-04)**

* Fix a date parsing bug in Python versions <3.7 (#114)

**0.23.0 (2019-09-03)**

* Add `toot tui`, new and improved TUI implemented written with the help of the
  [urwid](http://urwid.org/) library
* Deprecate `toot curses`. It will show a deprecation notice when started. To be
  removed in a future release
* Add `--editor` option to `toot post` to allow composing toots in an editor
  (#90)
* Fix config file permissions, set them to 0600 when creating the initial config
  file (#109)
* Add user agent string to all requests, fixes interaction with instances
  protected by Cloudflare (#106)

**0.22.0 (2019-08-01)**

* **BREAKING:** Dropped support for Python 3.3
* Add `toot notifications` to show notifications (thanks @dlax)
* Add posting and replying to curses interface (thanks @Skehmatics)
* Add `--language` option to `toot post`
* Enable attaching upto 4 files via `--media` option on `toot post`

**0.21.0 (2019-02-15)**

* **BREAKING:** in `toot timeline` short argument for selecting a list is no
  longer `-i`, this has been changed to select the instance, so that it is the
  same as on other commands, please use the long form `--list` instead
* Add `toot reblogged_by` to show who reblogged a status (#88)
* Add `toot thread` to show a status with its replies (#87)
* Better handling of wide characters (eastern scripts, emojis) (#84)
* Improved `timeline`, nicer visuals, and it will now ask to show next batch of
  toots, unless given the `--once` option
* Add public/local/tag timelines to `timeline` and `curses`
* Support for boosting and favouriting in `toot curses`, press `f`/`b` (#88,
  #93)

**0.20.0 (2019-02-01)**

* Enable interaction with instances using http instead of https (#56)
* Enable proxy usage via environment variables (#47)
* Make `toot post` prompt for input if no text is given (#82)
* Add post-related commands: `favourite`, `unfavourite`, `reblog`, `unreblog`,
  `pin` & `unpin` (#75)

**0.19.0 (2018-06-27)**

* Add support for replying to a toot (#6)
* Add `toot delete` command for deleting a toot (#54)
* Add global `--quiet` flag to silence output (#46)
* Make `toot login` provide browser login, and `toot login_cli` log in via
  console. This makes it clear what's the preferred option.
* Use Idempotency-Key header to prevent multiple toots being posted if request
  is retried
* Fix a bug where all media would be marked as sensitive

**0.18.0 (2018-06-12)**

* Add support for public, tag and list timelines in `toot timeline` (#52)
* Add `--sensitive` and `--spoiler-text` options to `toot post` (#63)
* Curses app improvements (respect sensitive content, require keypress to show,
  add help modal, misc improvements)

**0.17.1 (2018-01-15)**

* Create config folder if it does not exist (#40)
* Fix packaging to include `toot.ui` package (#41)

**0.17.0 (2018-01-15)**

* Changed configuration file format to allow switching between multiple logged
  in accounts (#32)
* Respect XDG_CONFIG_HOME environment variable to locate config home (#12)
* Dynamically calculate left window width, supports narrower windows (#27)
* Redraw windows when terminal size changes (#25)
* Support scrolling the status list
* Fetch next batch of statuses when bottom is reached
* Support up/down arrows (#30)
* Misc visual improvements

**0.16.2 (2018-01-02)**

* No changes, pushed to fix a packaging issue

**0.16.1 (2017-12-30)**

* Fix bug with app registration

**0.16.0 (2017-12-30)**

* **BREAKING:** Dropped support for Python 2, because it's a pain to support and
  caused bugs with handling unicode.
* Remove hacky `login_2fa` command, use `login_browser` instead
* Add `instance` command
* Allow `post`ing media without text (#24)

**0.15.1 (2017-12-12)**

* Fix crash when toot's URL is None (#33), thanks @veer66

**0.15.0 (2017-09-09)**

* Fix Windows compatibility (#18)

**0.14.0 (2017-09-07)**

* Add `--debug` option to enable debug logging instead of using the `TOOT_DEBUG`
  environment variable.
* Fix: don't read requirements.txt from setup.py, this fails when packaging deb
  and potentially in some other cases (see #18)

**0.13.0 (2017-08-26)**

* Allow passing `--instance` and `--email` to login command
* Add `login_browser` command for proper two factor authentication through the
  browser (#19, #23)

**0.12.0 (2017-05-08)**

* Add option to disable ANSI color in output (#15)
* Return nonzero error code on error (#14)
* Change license to GPLv3

**0.11.0 (2017-05-07)**

* Fix error when running toot from crontab (#11)
* Minor tweaks

**0.10.0 (2017-04-26)**

* Add commands: `block`, `unblock`, `mute`, `unmute`
* Internal improvements

**0.9.1 (2017-04-24)**

* Fix conflict with curses package name

**0.9.0 (2017-04-21)**

* Add `whois` command
* Add experimental `curses` app for viewing the timeline

**0.8.0 (2017-04-19)**

* **BREAKING:** Renamed command `2fa` to `login_2fa`
* It is now possible to pipe text into `toot post`

**0.7.0 (2017-04-18)**

* **WARNING:** Due to changes in configuration format, after upgrading to this
  version, you will be required to log in to your Mastodon instance again.
* Experimental 2FA support (#3)
* Do not create a new application for each login

**0.6.0 (2017-04-17)**

* Add `whoami` command
* Migrate from `optparse` to `argparse`

**0.5.0 (2017-04-16)**

* Add `search`, `follow` and `unfollow` commands
* Migrate from `optparse` to `argparse`

**0.4.0 (2017-04-15)**

* Add `upload` command to post media
* Add `--visibility` and `--media` options to `post` command

**0.3.0 (2017-04-13)**

* Add: view timeline
* Require an explicit login

**0.2.1 (2017-04-13)**

* Fix invalid requirements in setup.py

**0.2.0 (2017-04-12)**

* Bugfixes

**0.1.0 (2017-04-12)**

* Initial release

